ProSHADE: Namespace Members

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

### - i -

- initialiseAllMemory() : ProSHADE_internal_sphericalHarmonics
- initialiseFFTWPlans() : ProSHADE_internal_sphericalHarmonics
- initialiseInverseSHComputation() : ProSHADE_internal_overlay
- initialSplitDiscreteTransform() : ProSHADE_internal_sphericalHarmonics
- isAxisUnique() : ProSHADE_internal_maths
- isBandWithinShell() : ProSHADE_internal_distances
- isFileMAP() : ProSHADE_internal_io
- isFilePDB() : ProSHADE_internal_io
- isSymmetrySame() : ProSHADE_internal_symmetry